@@ -2,7 +2,6 @@
 use eva_common::actions::{self, ACTION_TOPIC};
 use eva_common::events::{RawStateEventOwned, RAW_STATE_TOPIC};
 use eva_common::prelude::*;
-use lazy_static::lazy_static;
 use serde::Deserialize;
 use std::collections::HashMap;
 use std::sync::Mutex;
@@ -10,10 +9,6 @@ use std::time::{Duration, Instant};
 use ttl_cache::TtlCache;
 use uuid::Uuid;
 
-lazy_static! {
-    static ref NEED_PANIC: Mutex<Option<Duration>> = <_>::default();
-}
-
 const RAW_STATE_CACHE_MAX_CAPACITY: usize = 1_000_000;
 
 pub struct RawStateCache {
@@ -72,26 +67,6 @@ impl RawStateCache {
     }
 }
 
-/// # Panics
-///
-/// Will panic if the mutex is poisoned
-pub fn set_poc(panic_in: Option<Duration>) {
-    *NEED_PANIC.lock().unwrap() = panic_in;
-}
-
-/// # Panics
-///
-/// Will panic if the mutex is poisoned
-pub fn poc() {
-    if let Some(delay) = *NEED_PANIC.lock().unwrap() {
-        bmart::process::suicide(delay + Duration::from_secs(1), false);
-        std::thread::spawn(move || {
-            std::thread::sleep(delay);
-            std::process::exit(1);
-        });
-    }
-}
-
 #[path = "actt.rs"]
 pub mod actt;
 #[path = "transform.rs"]
